from enum import Enum


class TypeListe(Enum):
    Input = 'E'
    Output = 'S'


class TypeServiListe(Enum):
    GlobaleBoite = 'GLOBAL_BTE'
    GlobalePilulier = 'GLOBAL_PIL'
    Nominatif = 'NOMINATIF'
    Exotique = 'EXOTIQUE'
    RiedlBoite = 'RIEDL_BTE'     # Riedl mode
    Retour = 'RETOUR'            # Riedl mode
    Prelevement = 'PRELEVEMENT'  # Riedl mode
    RetraitLot = 'RETRAIT'       # Riedl mode
    Perimee = 'PERIMEE'          # Riedl mode


class EtatListe(Enum):
    Vierge = 'V'
    EnCours = 'E'
    Solde = 'S'
    Archive = 'Z'


DEFAULT_PROFILS = [
    'ECO-DEX',
    'DEENOVA',
    'ADMIN',
    'TECH'
]

CUSTOM_PROFILS = [
    'PREPARATEUR',
    'PHARMACIEN',
    'REFERENT',
    'INFIRMIER'
]

RIEDL_PRIORITY = [
    (1, 'Haute'),
    (3, 'Normale'),
    (5, 'Faible'),
]
